#!/usr/bin/python
#    Copyright 2007 Stuart Stevenson
#    Derived from a work by Chris Radek which was
#    derived from a work by John Kasunich and Jeff Epler
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


from vismach import *
import hal
import math
import sys

# give endpoint Z values and radii
# resulting cylinder is on the Z axis
class HalToolCylinder(CylinderZ):
    def __init__(self, comp, *args):
	CylinderZ.__init__(self, *args)
	self.comp = comp

    def coords(self):
        return -self.comp.tool_length, .875, 0, .875

c = hal.component("5axhydrotelgui")
c.newpin("joint0", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("joint1", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("joint2", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("joint3", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("joint4", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("joint5", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("joint6", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("joint7", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("joint8", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("tool_length", hal.HAL_FLOAT, hal.HAL_IN)
c.newpin("tool_dia", hal.HAL_FLOAT, hal.HAL_IN)
c.ready()

pivot_len=5.25
tool_radius=1

for setting in sys.argv[1:]: exec setting

#########################################################################

tooltip = Capture()
tool = Collection([HalTranslate([tooltip], c, "tool_length", 0,0,-1),
                   HalToolCylinder(c),
                   CylinderZ(0, 4, 1, 4)
                  ,CylinderZ(.9, 5, 2.5, 5)
                  ,Box(-7.5,-7.5,2, 7.5,7.5,37.5)
                   ])

tool = Translate([tool], 0, 0, -pivot_len)

tool = Collection([tool,
                   CylinderY(4,3, .5,3)
                  ,CylinderY(-2,2.5,2,2.5)
                   ])

tool = HalRotate([tool],c,"joint3",1,1,0,0)

#########################################################################

wrist = Collection([tool,
                    Box(-16,-8,-4, -8,8,36)
                    ,Box(8,-8,-4, 16,8,36)
                    ])

wrist = HalRotate([wrist],c,"joint4",1,0,1,0)

#########################################################################

ram = Collection([wrist,
                  Box(-16,8,-4, 16,18,60)
                  ])

ram = Translate([ram], 0,0,0)

ram = HalTranslate([ram],c,"joint2",0,0,1)

ram = Collection([ram,
                  Box(-26,22,16, 26,160,80)
                 ,Box(-12,18,12, 12,22,70)
                  ])
    
ram = HalTranslate([ram],c,"joint1",0,1,0)

#########################################################################

Xtable = Capture()

table = Collection([Xtable,
                  Box(-61,-20,-60,  61,20,-68)
                  ])

table = HalTranslate([table],c,"joint0",-1,0,0)

#########################################################################

work = Capture()

base = Collection([work,
                  Box(-30,22,-110, 30,50,-74)
     	         ,Box(-30,50,-110, 30,130,16)
                 ,Box(140,22,-70, -140,-22,-110)
        ])

#########################################################################

model = Collection([ram, table, base])

#########################################################################

main(model, tooltip, work, 200)
